// XRD Calculator
// $Author: Jeffrey J Weimer$
// SVN History: $Revision: 1242 $ on $Date: 2009-12-08 08:12:44 -0800 (Tue, 08 Dec 2009) $

#pragma rtGlobals=1
#pragma IgorVersion=6.10
#pragma version = 2.1

#pragma IndependentModule=XRDCalculator

Menu "Misc"
	Submenu "Panels"
		"XRD Input",/Q,MakeXRDInputPanel()
	end
end

// Panel

Function MakeXRDInputPanel()

	if (WinType("XRDInput")==0)
		InitializeXRD()
		ShowXRDPanel()
		CalculateTwoThetas()
		ChangeIntensities()
		UpdateGraph()
	else
		DoWindow/F XRDInput
	endif
	
	return 0
end

Function InitializeXRD()

	if (!DataFolderExists("root:Packages:XRDCalculator"))
		DFREF cdf = GetDataFolderDFR()
		SetDataFolder root:
		NewDataFolder/O/S Packages
		NewDataFolder/S XRDCalculator
		make/N=18/T plabel
		make/N=18 dhkl, yn
		make/N=18 twotheta1A, twotheta2A, Iratio1A, Iratio2A, Iratio1o, Iratio2o
		make/N=18 twotheta1B, twotheta2B, Iratio1B, Iratio2B
		make/N=(18,3) hkl, StructureDeltas
		variable/g aoA=0.3789, aoB=0.3789, xB=0, lambda=0.1542, KA, KB, sA=1, sB=1
		MakehklMatrix()
		MakeStructureDeltas()
		MakeIoratios()
		SetDataFolder cdf
	endif
	
	return 0

end

Function MakehklMatrix()

	wave hkl = root:Packages:XRDCalculator:hkl
	
	hkl[0,2][0] = 1
	hkl[3,8][0] = 2
	hkl[9,17][0] = 3

	hkl[][1] = 0
	hkl[1,2][1] = 1
	hkl[4,5][1] = 1
	hkl[6,8][1] = 2
	hkl[10][1] = 1
	hkl[11][1] = 2
	hkl[12][1] = 3
	hkl[13][1] = 1
	hkl[14][1] = 2
	hkl[15,17][1] = 3

	hkl[][2] = 0
	hkl[2][2] = 1
	hkl[5][2] = 1
	hkl[7][2] = 1
	hkl[8][2] = 2
	hkl[13,15][2] = 1
	hkl[16][2] = 2
	hkl[17][2] = 3
	
	return 0
end

Function MakeStructureDeltas()

	wave hkl = root:Packages:XRDCalculator:hkl
	wave StrD = root:Packages:XRDCalculator:StructureDeltas
	
	StrD[][] = NaN
	
	StrD[][0] = 1

	StrD[][1] = ( ( (xisodd(hkl[p][0])*xisodd(hkl[p][1])*xisodd(hkl[p][2])) == 1) || (xisodd(hkl[p][0])+xisodd(hkl[p][1])+xisodd(hkl[p][2]) == 0)) == 1 ? 1 : NaN
	
	StrD[][2] = (xisodd((hkl[p][0])^2 + (hkl[p][1])^2 + (hkl[p][2])^2)) == 0 ? 1 : NaN
	
	return 0

end

Function xisodd(v)
	variable v
	
	return (mod(v,2))
	
end

Function MakeIoRatios()

	wave hkl = root:Packages:XRDCalculator:hkl
	wave ir1o = root:Packages:XRDCalculator:Iratio1o
	wave ir2o = root:Packages:XRDCalculator:Iratio2o
	
	ir1o = 1/((hkl[p][0])^2 + (hkl[p][1])^2  + (hkl[p][2])^2)
	ir2o = ir1o/4
	
	ir2o[0]*= 2	// (100) overlaps
	ir2o[1]*= 2	// (110) overlaps
	ir2o[2]*=2	// (111) overlaps

	return 0

end

Function ShowXRDPanel()

	NewPanel/K=1/W=(665,117,948,233)/N=XRDInput as "XRD Input"
	ModifyPanel fixedSize=1, noEdit=1
	SetDrawLayer UserBack
	DrawLine 2,57,280,57
	
	TabControl SetAlloy,pos={6,1},size={100,20},proc=SetAlloy,tabLabel(0)="A"

	Button report, pos={236,4},size={35,20},title="->R",fSize=12,proc=ToReport

	// controls affecting graph
	
	CheckBox tagit title="T",proc=TagOnOff,fSize=12, pos={230,90}

	SetVariable thetastart,pos={10,89},size={100,19},proc=SetTwoTheta,title="|< [o]"
	SetVariable thetastart,fSize=12,limits={0,90,5},value= _NUM:10
	SetVariable thetaend,pos={120,89},size={100,19},proc=SetTwoTheta,title=">| [o]"
	SetVariable thetaend,fSize=12,limits={10,360,5},value= _NUM:160

	SetVariable intensity,pos={162,64},size={110,19},proc=UpdateIRatioScale,title="Max I/Io"
	SetVariable intensity,fSize=12,limits={0.1,1.5,0.05},value= _NUM:1.05

	// controls affecting angles
		
	SetVariable lambda,pos={10,63},size={140,20},proc=UpdateAngles,title="\\F'Symbol' l\\F'Geneva' [nm]"
	SetVariable lambda,fSize=12
	SetVariable lambda,limits={0,inf,0.01},value= root:Packages:XRDCalculator:lambda

	SetVariable ao,pos={127,29},size={150,19},proc=UpdateAngles,title="ao [nm]"
	SetVariable ao,fSize=12
	SetVariable ao,limits={0,inf,0.01},value= root:Packages:XRDCalculator:aoA

	// controls affecting intensities

	PopupMenu xstructure,pos={9,29},size={108,20},proc=ChangeStructure,title="Structure"
	PopupMenu xstructure,fSize=12,mode=1,popvalue="SC",value= #"\"SC;FCC;BCC;\""
	
	SetVariable setXB,pos={86,4},size={80,19},title="xB",fSize=12, proc=SetxB
	SetVariable setXB,limits={0,1,0.1},value=root:Packages:XRDCalculator:xB, disable=1

	CheckBox alloyOn,pos={166,4},size={34,16},title="Alloy",fSize=12
	CheckBox alloyOn,value= 0, proc=TurnOnOffAlloy
	
	return 0

End

Function SetAlloy(tca) : TabControl
	STRUCT WMTabControlAction &tca
	
	NVAR sA = root:Packages:XRDCalculator:sA
	NVAR sB = root:Packages:XRDCalculator:sB
	
	switch( tca.eventCode )
		case 2: // mouse up
			switch(tca.tab)
				case 0:
					SetVariable ao,value= root:Packages:XRDCalculator:aoA
					PopupMenu xstructure,mode=sA
					break
				case 1:
					SetVariable ao,value= root:Packages:XRDCalculator:aoB
					PopupMenu xstructure,mode=sB
					break
			endswitch
	endswitch

	return 0
End

// Functions to Change Graph

Function UpdateGraph()

	if (WinType("DiffractionPattern")==0)
		ReMakeDiffractionPattern()
	endif

	variable Vo

	DoWindow/F XRDInput
	ControlInfo intensity
	SetAxis/W=DiffractionPattern left 0,V_value
	ControlInfo thetastart
	Vo = V_value
	ControlInfo thetaend
	SetAxis/W=DiffractionPattern bottom Vo, V_value
	
	return 0

end

Function UpdateIRatioScale(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			SetAxis/W=DiffractionPattern left 0,sva.dval
			break
	endswitch

	return 0
End

Function SetTwoTheta(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			GetAxis/W=DiffractionPattern/Q bottom
			strswitch(sva.ctrlName)
				case "thetastart":
					SetAxis/W=DiffractionPattern bottom sva.dval, V_max
					break
				case "thetaend":
					SetAxis/W=DiffractionPattern bottom V_min, sva.dval
					break
			endswitch
			break
	endswitch

	return 0
End

// Functions to Change Angles

Function UpdateAngles(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			CalculateTwoThetas()
			break
	endswitch

	return 0
End

Function CalculateTwoThetas()

	NVAR lambda = root:Packages:XRDCalculator:lambda

	NVAR aoA = root:Packages:XRDCalculator:aoA
	NVAR aoB = root:Packages:XRDCalculator:aoB
	
	wave dhkl = root:Packages:XRDCalculator:dhkl
	wave hkl = root:Packages:XRDCalculator:hkl

	wave twotheta1A = root:Packages:XRDCalculator:twotheta1A
	wave twotheta2A = root:Packages:XRDCalculator:twotheta2A

	wave twotheta1B = root:Packages:XRDCalculator:twotheta1B
	wave twotheta2B = root:Packages:XRDCalculator:twotheta2B
	
	duplicate/FREE dhkl sintheta
	
	// component A
	
	dhkl = aoA/sqrt((hkl[p][0])^2+(hkl[p][1])^2+(hkl[p][2])^2)
	
	sintheta = lambda/(2*dhkl)
	twotheta1A = sintheta <= 1 ? (asin(sintheta)*(180/Pi)) : (90 + asin(sintheta-1)*(180/Pi))
	twotheta1A*=2
	
	sintheta = lambda/dhkl
	twotheta2A = sintheta <= 1 ? (asin(sintheta)*(180/Pi)) : (90 + asin(sintheta-1)*(180/Pi))
	twotheta2A*=2
	
	// component B
	
	dhkl = aoB/sqrt((hkl[p][0])^2+(hkl[p][1])^2+(hkl[p][2])^2)
	
	sintheta = lambda/(2*dhkl)
	twotheta1B = sintheta <= 1 ? (asin(sintheta)*(180/Pi)) : (90 + asin(sintheta-1)*(180/Pi))
	twotheta1B*=2
	
	sintheta = lambda/dhkl
	twotheta2B = sintheta <= 1 ? (asin(sintheta)*(180/Pi)) : (90 + asin(sintheta-1)*(180/Pi))
	twotheta2B*=2
	
	return 0
end

// Functions to Change Intensities

Function ChangeStructure(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa

	NVAR sA = root:Packages:XRDCalculator:sA
	NVAR sB = root:Packages:XRDCalculator:sB	
	
	switch( pa.eventCode )
		case 2: // mouse up
			// pa.popNum: 0 - SC, 1 - FCC, 2 - BCC
			ControlInfo SetAlloy
			switch(V_value)
				case 0:	// component A
					sA = pa.popNum
					break
				case 1:	// component B
					sB = pa.popNum
					break
			endswitch
			ControlInfo TagIt
			if (V_value)
				TagAll(0)
				ChangeIntensities()
				TagAll(1)
			else
				ChangeIntensities()
			endif
			break
	endswitch

	return 0
End

Function TurnOnOffAlloy(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba
	
	NVAR sA = root:Packages:XRDCalculator:sA

	switch( cba.eventCode )
		case 2: // mouse up
			SetVariable setXB, disable=(cba.checked!=1)
			if (cba.checked)
				TabControl SetAlloy,tabLabel(1)="B", disable=0
			else
				TabControl SetAlloy,tabLabel(1)=""
				SetVariable ao,value= root:Packages:XRDCalculator:aoA
				PopupMenu xstructure,mode=sA
			endif
			ControlInfo TagIt
			if (V_value)
				TagAll(0)
				ChangeIntensities()
				TagAll(1)
			else
				ChangeIntensities()
			endif
			break
	endswitch

	return 0
End

Function SetxB(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	NVAR xB = root:Packages:XRDCalculator:xB

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			xB = sva.dval
			ChangeIntensities()
			break
	endswitch

	return 0
End

Function ChangeIntensities()
	
	wave ir1A = root:Packages:XRDCalculator:Iratio1A
	wave ir2A = root:Packages:XRDCalculator:Iratio2A
	wave ir1B = root:Packages:XRDCalculator:Iratio1B
	wave ir2B = root:Packages:XRDCalculator:Iratio2B
	wave ir1o = root:Packages:XRDCalculator:Iratio1o
	wave ir2o = root:Packages:XRDCalculator:Iratio2o
	wave Str = root:Packages:XRDCalculator:StructureDeltas
	
	NVAR KA = root:Packages:XRDCalculator:KA
	NVAR KB = root:Packages:XRDCalculator:KB	
	NVAR sA = root:Packages:XRDCalculator:sA
	NVAR sB = root:Packages:XRDCalculator:sB	
	NVAR xB = root:Packages:XRDCalculator:xB
	
	ControlInfo AlloyOn
	if (V_value)
		KA = (1-xB) == 0 ? NaN : (1 - xB)
		KB = xB == 0 ? NaN : xB
	else
		KA = 1
		KB = NaN
	endif
	
	ir1A=ir1o*Str[p][sA-1]*KA
	ir2A=ir2o*Str[p][sA-1]*KA
	ir1B=ir1o*Str[p][sB-1]*KB
	ir2B=ir2o*Str[p][sB-1]*KB

	return 0
End

// Other Functions

Function ToReport(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			MakeReport()
			break
	endswitch

	return 0
End

Function TagOnOff(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba

	switch( cba.eventCode )
		case 2: // mouse up
			TagAll(cba.checked)
			break
	endswitch

	return 0
End

Function TagAll(onoff)
	variable onoff
	
	onoff = onoff == 0 ? -1 : 1
	TagLines(onoff*1)
	TagLines(onoff*2)
	
	return 0
end
	

Function TagLines(how)
	variable how

	wave ir1A = root:Packages:XRDCalculator:Iratio1A
	wave ir2A = root:Packages:XRDCalculator:Iratio2A
	wave ir1B = root:Packages:XRDCalculator:Iratio1B
	wave ir2B = root:Packages:XRDCalculator:Iratio2B

	wave hkl = root:Packages:XRDCalculator:hkl
	
	NVAR KA = root:Packages:XRDCalculator:KA
	NVAR KB = root:Packages:XRDCalculator:KB	

	make/N=17/T/FREE plabel
	variable ic
	string theTag, theLine, theN
	
	plabel = num2str(hkl[p][0]) + num2str(hkl[p][1]) + num2str(hkl[p][2])

	theN = num2str(abs(how))
	
	switch(how)
		case -2:
			if (numtype(KA)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir2A[ic])==0)
						sprintf theTag, "tag_A2%s%s", theN,plabel[ic]
						Tag/K/N=$theTag
					endif
				endfor
			endif
			if (numtype(KB)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir2B[ic])==0)
						sprintf theTag, "tag_B2%s%s", theN,plabel[ic]
						Tag/K/N=$theTag
					endif
				endfor
			endif
			break
		case -1:
			if (numtype(KA)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir1A[ic])==0)
						sprintf theTag, "tag_A1%s%s", theN,plabel[ic]
						Tag/K/N=$theTag
					endif
				endfor
			endif
			if (numtype(KB)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir1B[ic])==0)
						sprintf theTag, "tag_B1%s%s", theN,plabel[ic]
						Tag/K/N=$theTag
					endif
				endfor
			endif
			break
		case 1:
			if (numtype(KA)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir1A[ic])==0)
						sprintf theLine, "\\JC\\Z09A %s (%s)\r(\\{%s,TagVal(2)},\\{%s,TagVal(1)})", theN, plabel[ic],"\"%3.3g\"", "\"%3.2f\""
						sprintf theTag, "tag_A1%s%s", theN,plabel[ic]
						Tag/C/N=$theTag/F=0/L=0/TL=0/A=RB/O=45/X=0/Y=2/I=1/AO=0 Iratio1A, ic, theLine
					endif
				endfor
			endif
			if (numtype(KB)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir1B[ic])==0)
						sprintf theLine, "\\JC\\Z09B %s (%s)\r(\\{%s,TagVal(2)},\\{%s,TagVal(1)})", theN, plabel[ic],"\"%3.3g\"", "\"%3.2f\""
						sprintf theTag, "tag_B1%s%s", theN,plabel[ic]
						Tag/C/N=$theTag/F=0/L=0/TL=0/A=RB/O=45/X=0/Y=2/I=1/AO=0 Iratio1B, ic, theLine
					endif
				endfor
			endif
			break
		case 2:
			if (numtype(KA)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir2A[ic])==0)
						sprintf theLine, "\\JC\\Z09A %s (%s)\r(\\{%s,TagVal(2)},\\{%s,TagVal(1)})", theN, plabel[ic],"\"%3.3g\"", "\"%3.2f\""
						sprintf theTag, "tag_A2%s%s", theN,plabel[ic]
						Tag/C/N=$theTag/F=0/L=0/TL=0/A=RB/O=45/X=0/Y=2/I=1/AO=0 Iratio2A, ic, theLine
					endif
				endfor
			endif
			if (numtype(KB)==0)
				for (ic=0;ic<17;ic+=1)
					if (numtype(ir2B[ic])==0)
						sprintf theLine, "\\JC\\Z09B %s (%s)\r(\\{%s,TagVal(2)},\\{%s,TagVal(1)})", theN, plabel[ic],"\"%3.3g\"", "\"%3.2f\""
						sprintf theTag, "tag_B2%s%s", theN,plabel[ic]
						Tag/C/N=$theTag/F=0/L=0/TL=0/A=RB/O=45/X=0/Y=2/I=1/AO=0 Iratio2B, ic, theLine
					endif
				endfor
			endif
			break
	endswitch
	
	return 0
	
end

//Function MakeReport()
//
//	wave ir1A = root:Packages:XRDCalculator:Iratio1A
//	wave ir2A = root:Packages:XRDCalculator:Iratio2A
//	wave ir1B = root:Packages:XRDCalculator:Iratio1B
//	wave ir2B = root:Packages:XRDCalculator:Iratio2B
//
//	wave twotheta1A = root:Packages:XRDCalculator:twotheta1A
//	wave twotheta2A = root:Packages:XRDCalculator:twotheta2A
//	wave twotheta1B = root:Packages:XRDCalculator:twotheta1B
//	wave twotheta2B = root:Packages:XRDCalculator:twotheta2B
//
//	wave hkl = root:Packages:XRDCalculator:hkl
//	
//	NVAR KA = root:Packages:XRDCalculator:KA
//	NVAR KB = root:Packages:XRDCalculator:KB	
//	NVAR sA = root:Packages:XRDCalculator:sA
//	NVAR sB = root:Packages:XRDCalculator:sB	
//	NVAR xB = root:Packages:XRDCalculator:xB
//	NVAR aoA = root:Packages:XRDCalculator:aoA
//	NVAR aoB = root:Packages:XRDCalculator:aoB
//	NVAR lambda = root:Packages:XRDCalculator:lambda
//
//	make/N=18/T/FREE plabel
//	make/n=3/T/FREE xst={"SC","FCC","BCC"}
//
//	duplicate/FREE ir1A i1A
//	duplicate/FREE ir2A i2A
//	duplicate/FREE ir1B i1B
//	duplicate/FREE ir2B i2B
//	
//	duplicate/FREE twotheta1A tt1A
//	duplicate/FREE twotheta2A tt2A
//	duplicate/FREE twotheta1B tt1B
//	duplicate/FREE twotheta2A tt2A
//	
//	variable ic=1
//	string theReport=""
//	
//	if (WinType("XRDReport")==0)
//		NewNotebook/F=1/N=XRDReport as "XRD Report"
//		ic = 0
//	endif
//	
//	Notebook XRDReport, selection={endOfFile,endOfFile}, showRuler=(0)
//	if (ic)
//		Notebook XRDReport specialChar={1,0,""}
//	endif
//
//	sprintf theReport,"Date: %s     Time: %s\r", date(), time()
//	Notebook XRDReport, text=theReport
//	Notebook XRDReport, scaling={50,50}, picture={DiffractionPattern,-5,1}
//
//	sprintf theReport, "\rWavelength: %5.4f nm",lambda
//	ControlInfo AlloyOn
//	if (V_value)
//		sprintf theReport, "%s\rAlloy at Composition xB = %3.2f", theReport,xB
//		sprintf theReport, "%s\r(A) structure: %s\t ao: %5.4f nm",theReport,xst[sA-1],aoA
//		sprintf theReport, "%s\r(B) structure: %s\t ao: %5.4f nm",theReport,xst[sB-1],aoB
//		sprintf theReport, "%s\rAlloy\tOrder\t Plane\t\tAngle\t100*I/Io", theReport
//	else
//		sprintf theReport, "%s\r(A) structure: %s\t ao: %5.4f nm",theReport,xst[sA-1],aoA
//		sprintf theReport, "%s\rPure\tOrder\t Plane\t\tAngle\t100*I/Io", theReport
//	endif
//	
//	plabel = num2str(hkl[p][0]) + num2str(hkl[p][1]) + num2str(hkl[p][2])
//	
//	for (ic=0;ic<18;ic+=1)
//		if (numtype(KA)==0)
//			for (ic=0;ic<17;ic+=1)
//				if (numtype(ir1A[ic])==0)
//					sprintf theReport, "%s\r  A\t  1\t(%s)\t\t%4.1f\t  %3.2f", theReport,plabel[ic],twotheta1A[ic],ir1A[ic]*100
//				endif
//				if (numtype(ir2A[ic])==0)
//					sprintf theReport, "%s\r  A\t  2\t(%s)\t\t%4.1f\t  %3.2f", theReport,plabel[ic],twotheta2A[ic],ir2A[ic]*100
//				endif
//			endfor
//		endif
//		if (numtype(KB)==0)
//			for (ic=0;ic<18;ic+=1)
//				if (numtype(ir1B[ic])==0)
//					sprintf theReport, "%s\r  B\t  1\t(%s)\t\t%3.3g\t  %3.2f", theReport,plabel[ic],twotheta1B[ic],ir1B[ic]*100
//				endif
//				if (numtype(ir2B[ic])==0)
//					sprintf theReport, "%s\r  B\t  2\t(%s)\t\t%3.3g\t  %3.2f", theReport,plabel[ic],twotheta2B[ic],ir2B[ic]*100
//				endif
//			endfor
//		endif
//
//	endfor
//	
//	theReport+="\r--\r"
//	
//	Notebook XRDReport, text=theReport
//	return 0
//
//end

Function MakeReport()

	wave ir1A = root:Packages:XRDCalculator:Iratio1A
	wave ir2A = root:Packages:XRDCalculator:Iratio2A
	wave ir1B = root:Packages:XRDCalculator:Iratio1B
	wave ir2B = root:Packages:XRDCalculator:Iratio2B

	wave twotheta1A = root:Packages:XRDCalculator:twotheta1A
	wave twotheta2A = root:Packages:XRDCalculator:twotheta2A
	wave twotheta1B = root:Packages:XRDCalculator:twotheta1B
	wave twotheta2B = root:Packages:XRDCalculator:twotheta2B

	wave hkl = root:Packages:XRDCalculator:hkl
	
	NVAR KA = root:Packages:XRDCalculator:KA
	NVAR KB = root:Packages:XRDCalculator:KB	
	NVAR sA = root:Packages:XRDCalculator:sA
	NVAR sB = root:Packages:XRDCalculator:sB	
	NVAR xB = root:Packages:XRDCalculator:xB
	NVAR aoA = root:Packages:XRDCalculator:aoA
	NVAR aoB = root:Packages:XRDCalculator:aoB
	NVAR lambda = root:Packages:XRDCalculator:lambda
	
	variable npts = numpnts(ir1A), ic=1
	string theReport=""

	make/N=(2*npts)/T/FREE plabelA, plabelB
	make/n=3/T/FREE xst={"SC","FCC","BCC"}	
	
	if (WinType("XRDReport")==0)
		NewNotebook/F=1/N=XRDReport as "XRD Report"
		ic = 0
	endif
	
	Notebook XRDReport, selection={endOfFile,endOfFile}, showRuler=(0)
	if (ic)
		Notebook XRDReport specialChar={1,0,""}
	endif

	sprintf theReport,"Date: %s     Time: %s\r", date(), time()
	Notebook XRDReport, text=theReport
	Notebook XRDReport, scaling={50,50}, picture={DiffractionPattern,-5,1}

	sprintf theReport, "\rWavelength: %5.4f nm",lambda
	
	plabelA[0,npts-1] = "1{" + num2str(hkl[p][0]) + num2str(hkl[p][1]) + num2str(hkl[p][2]) + "}"
	plabelA[npts,] = "2{" + num2str(hkl[p-npts][0]) + num2str(hkl[p-npts][1]) + num2str(hkl[p-npts][2]) + "}"
	plabelB = plabelA
	Concatenate/NP/O {ir1A,ir2A}, irA
	Concatenate/NP/O {ir1B,ir2B}, irB
	Concatenate/NP/O {twotheta1A,twotheta2A}, ttA
	Concatenate/NP/O {twotheta1B,twotheta2B}, ttB
	
	Sort ttA, ttA, irA, plabelA
	Sort ttB, ttB, irB, plabelB

	ControlInfo/W=XRDInput AlloyOn
	if (V_value)
		sprintf theReport, "%s\rAlloy at Composition xB = %3.2f", theReport,xB
		sprintf theReport, "%s\r(A) structure: %s\t ao: %5.4f nm",theReport,xst[sA-1],aoA
		sprintf theReport, "%s\r(B) structure: %s\t ao: %5.4f nm",theReport,xst[sB-1],aoB
		sprintf theReport, "%s\r\tAngle\t\t100*I/Io\tn{Plane}", theReport
	else
		sprintf theReport, "%s\r(A) structure: %s\t ao: %5.4f nm",theReport,xst[sA-1],aoA
		sprintf theReport, "%s\r\tAngle\t\t100*I/Io\tn{Plane}", theReport
	endif
	
	if (numtype(KA)==0)
		for (ic=0;ic<2*npts;ic+=1)
			if (numtype(irA[ic])==0)
				sprintf theReport, "%s\r\t%4.1f\t\t %3.1f\t  A\t%s", theReport,ttA[ic],irA[ic]*100,plabelA[ic]
			endif
		endfor
	endif
	if (numtype(KB)==0)
		for (ic=0;ic<2*npts;ic+=1)
			if (numtype(irB[ic])==0)
				sprintf theReport, "%s\r\t%4.1f\t\t %3.1f\t  B\t%s", theReport,ttB[ic],irB[ic]*100,plabelB[ic]
			endif
		endfor
	endif
	KillWaves/Z irA, irB, ttA, ttB
	
	theReport+="\r--\r"
	
	Notebook XRDReport, text=theReport
	return 0

end

Function ReMakeDiffractionPattern()

	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:Packages:XRDCalculator:
	Display/W=(63,151,695,648)/N=DiffractionPattern Iratio2A vs twotheta2A as "Diffraction Pattern"
	AppendToGraph Iratio1A vs twotheta1A
	AppendToGraph Iratio2B vs twotheta2B
	AppendToGraph Iratio1B vs twotheta1B
	SetDataFolder fldrSav0
	ModifyGraph mode=1
	ModifyGraph lSize=4
	ModifyGraph rgb(Iratio2A)=(52428,1,1),rgb(Iratio1A)=(0,0,0),rgb(Iratio2B)=(52428,1,1)
	ModifyGraph rgb(Iratio1B)=(1,3,39321)
	ModifyGraph mirror=2
	ModifyGraph font="Helvetica"
	ModifyGraph minor=1
	ModifyGraph fSize=14
	Label left "\\Z16\\[0I/I\\Bo\\M"
	Label bottom "\\Z16\\[02\\F'Symbol'Q\\]0 [\\S o \\M]"
	
	DoUpdate
	return 0
End